@@ -1,9 +1,10 @@
 #!/usr/bin/env bash
-set -euo pipefail
+set -eo pipefail
 
 ROOT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")/.." && pwd)"
 LOCK_FILE="$ROOT_DIR/state/master_restart.lock"
-START_LOG="$ROOT_DIR/logs/start.log"
+LOG_DIR="$ROOT_DIR/logs"
+START_LOG="$LOG_DIR/start.log"
 CODEX_STAMP_FILE="$ROOT_DIR/state/npm_codex_install.stamp"
 CODEX_INSTALL_TTL="${CODEX_INSTALL_TTL:-86400}"
 
@@ -129,19 +130,19 @@ select_python_binary() {
     local major="${version_raw%%.*}"
     local minor="${version_raw#*.}"
     if [[ "$major" != "3" ]]; then
-      log_info "跳过 ${name} (版本 ${version_raw})：非 CPython 3.x"
+      log_line "跳过 ${name} (版本 ${version_raw})：非 CPython 3.x" >&2
       continue
     fi
     if [[ "$minor" =~ ^[0-9]+$ ]] && (( minor > 13 )); then
-      log_info "跳过 ${name} (版本 ${version_raw})：高于 3.13"
+      log_line "跳过 ${name} (版本 ${version_raw})：高于 3.13" >&2
       continue
     fi
     if [[ "$minor" =~ ^[0-9]+$ ]] && (( minor < 9 )); then
-      log_info "跳过 ${name} (版本 ${version_raw})：低于 3.9，可能缺少官方轮子"
+      log_line "跳过 ${name} (版本 ${version_raw})：低于 3.9，可能缺少官方轮子" >&2
       continue
     fi
     chosen="$name"
-    log_info "使用 Python 解释器：${chosen} (版本 ${version_raw})"
+    log_line "使用 Python 解释器：${chosen} (版本 ${version_raw})" >&2
     break
   done
 
@@ -217,18 +218,86 @@ else
   source .venv/bin/activate
 
   # 安装依赖
+  # 将 pip 输出重定向到日志文件，避免 BrokenPipe 错误
   log_info "开始执行 pip install -r $REQUIREMENTS_FILE"
-  pip install -r "$REQUIREMENTS_FILE"
-  log_info "依赖安装完成"
+  PIP_LOG_FILE="$LOG_DIR/pip_install_$(date +%Y%m%d_%H%M%S).log"
+  if pip install -r "$REQUIREMENTS_FILE" > "$PIP_LOG_FILE" 2>&1; then
+    log_info "依赖安装完成"
+  else
+    PIP_EXIT_CODE=$?
+    log_error "pip install 失败，退出码=$PIP_EXIT_CODE，详见 $PIP_LOG_FILE"
+    # 如果是 BrokenPipe (退出码 141)，验证依赖是否实际已安装
+    if [[ $PIP_EXIT_CODE -eq 141 ]]; then
+      log_info "检测到 BrokenPipe 错误，验证依赖完整性..."
+      # 验证关键依赖包是否可导入
+      if "$ROOT_DIR/.venv/bin/python" -c "import aiogram, aiohttp, aiosqlite" 2>/dev/null; then
+        log_info "依赖验证通过，BrokenPipe 可忽略，继续执行"
+      else
+        log_error "依赖验证失败，虽然是 BrokenPipe 但依赖未完整安装"
+        exit 1
+      fi
+    else
+      # 其他错误直接退出
+      exit $PIP_EXIT_CODE
+    fi
+  fi
 fi
 
 # 后台启动 master，日志落在 vibe.log
-nohup python master.py >> /dev/null 2>&1 &
-log_info "master 已后台启动，日志写入 vibe.log"
+# 显式传递重启标记环境变量（如果存在）
+if [[ -n "${MASTER_RESTART_EXPECTED:-}" ]]; then
+  log_info "检测到重启标记环境变量 MASTER_RESTART_EXPECTED=$MASTER_RESTART_EXPECTED"
+  export MASTER_RESTART_EXPECTED
+fi
 
-# 健康检查：等待 master 上线并验证关键 worker
-if ! python scripts/master_healthcheck.py --project hyphavibebotbackend; then
-  log_error "master 健康检查失败，请查看 logs/start.log / vibe.log"
+log_info "准备启动 master 进程..."
+nohup python master.py >> /dev/null 2>&1 &
+MASTER_PID=$!
+
+# 健壮性检查：确保进程成功启动
+if [[ -z "${MASTER_PID:-}" ]]; then
+  log_error "❌ 无法获取 master 进程 PID，启动失败"
+  log_error "可能原因：python 命令不可用或 master.py 有语法错误"
   exit 1
 fi
-log_info "master 健康检查通过"
+
+# 短暂等待后检查进程是否仍在运行
+sleep 0.5
+if ! kill -0 "$MASTER_PID" 2>/dev/null; then
+  log_error "❌ master 进程启动后立即退出（PID=$MASTER_PID）"
+  log_error "请检查："
+  log_error "  - master.py 是否有语法错误: python master.py"
+  log_error "  - 依赖是否完整: pip list | grep aiogram"
+  log_error "  - 最近的错误日志: tail -50 $ROOT_DIR/vibe.log"
+  exit 1
+fi
+
+log_info "master 已后台启动，PID=$MASTER_PID，日志写入 vibe.log"
+
+# 健康检查：等待 master 上线并验证关键 worker
+log_info "开始执行健康检查..."
+HEALTHCHECK_START=$(date +%s)
+
+if python scripts/master_healthcheck.py --project hyphavibebotbackend; then
+  HEALTHCHECK_END=$(date +%s)
+  HEALTHCHECK_DURATION=$((HEALTHCHECK_END - HEALTHCHECK_START))
+  log_info "✅ master 健康检查通过，耗时 ${HEALTHCHECK_DURATION}s"
+else
+  HEALTHCHECK_END=$(date +%s)
+  HEALTHCHECK_DURATION=$((HEALTHCHECK_END - HEALTHCHECK_START))
+  log_error "⚠️ master 健康检查失败，耗时 ${HEALTHCHECK_DURATION}s"
+  log_error "建议检查："
+  log_error "  - 进程状态: ps aux | grep 'python.*master.py'"
+  log_error "  - 启动日志: tail -100 $ROOT_DIR/logs/start.log"
+  log_error "  - 运行日志: tail -100 $ROOT_DIR/vibe.log"
+  log_error "  - 进程 PID: $MASTER_PID"
+
+  # 检查进程是否仍在运行
+  if kill -0 "$MASTER_PID" 2>/dev/null; then
+    log_info "master 进程仍在运行（PID=$MASTER_PID），允许继续启动"
+    log_info "⚠️ 请手动验证服务是否正常工作"
+  else
+    log_error "❌ master 进程已退出，启动失败"
+    exit 1
+  fi
+fi
