@@ -458,6 +458,8 @@ def test_projects_overview_hides_create_button(repo: ProjectRepository, tmp_path
     run_buttons = [label for label in labels if label.startswith("▶️ 启动")]
     stop_buttons = [label for label in labels if label.startswith("⛔️ 停止")]
     for label in run_buttons + stop_buttons:
+        if label == "⛔️ 停止全部项目":
+            continue
         assert "(" in label and label.endswith(")"), "运行/停止按钮应展示当前模型"
 
 
@@ -476,7 +478,7 @@ def test_manage_action_sends_inline_menu(repo: ProjectRepository, tmp_path: Path
     texts = [btn.text for row in buttons for btn in row]
     callbacks = [btn.callback_data for row in buttons for btn in row]
     assert "📝 编辑" in texts
-    assert "🧠 切换模型" in texts
+    assert any(text.startswith("🧠 切换模型（当前模型 ") for text in texts)
     assert "🗑 删除" in texts
     assert "project:switch_prompt:sample" in callbacks
     assert all(not cb.startswith("project:switch_to") for cb in callbacks)
@@ -501,10 +503,14 @@ def test_manage_button_handler_builds_keyboard(repo: ProjectRepository, tmp_path
     labels = [btn.text for row in markup.inline_keyboard for btn in row]
     assert "➕ 新增项目" in labels
     assert any(label.startswith("⚙️ 管理") for label in labels)
-    assert "🧠 模型" in labels
+    assert any(label.startswith("🧠 切换模型（当前模型 ") for label in labels)
     assert "🔁 全部切换模型" in labels
     rows = markup.inline_keyboard
-    assert any(row[0].text.startswith("⚙️ 管理") and row[1].text == "🧠 模型" for row in rows if len(row) >= 2), "项目管理列表应同排展示管理与模型按钮"
+    assert any(
+        row[0].text.startswith("⚙️ 管理") and row[1].text.startswith("🧠 切换模型（当前模型 ")
+        for row in rows
+        if len(row) >= 2
+    ), "项目管理列表应同排展示管理与模型按钮"
 
 
 def test_switch_prompt_displays_model_options(repo: ProjectRepository, tmp_path: Path):
