@@ -419,7 +419,8 @@ def test_task_list_search_flow(monkeypatch):
         user_message = DummyMessage(text="登录")
         await bot.on_task_list_search_keyword(user_message, state)
         assert await state.get_state() is None
-        assert message.edits and "*任务搜索结果*" in message.edits[-1]["text"]
+        # 在 MarkdownV2 模式下 * 会被转义
+        assert message.edits and ("*任务搜索结果*" in message.edits[-1]["text"] or "\\*任务搜索结果\\*" in message.edits[-1]["text"])
         assert "- 🛠️ 修复登录问题" not in message.edits[-1]["text"]
         assert "- ⚪ 修复登录问题" not in message.edits[-1]["text"]
         assert user_message.calls and "搜索完成" in user_message.calls[-1]["text"]
@@ -456,7 +457,8 @@ def test_task_list_search_cancel_restores_list(monkeypatch):
         cancel_message = DummyMessage(text="取消")
         await bot.on_task_list_search_keyword(cancel_message, state)
         assert await state.get_state() is None
-        assert message.edits and "*任务列表*" in message.edits[-1]["text"]
+        # 在 MarkdownV2 模式下 * 会被转义
+        assert message.edits and ("*任务列表*" in message.edits[-1]["text"] or "\\*任务列表\\*" in message.edits[-1]["text"])
         assert cancel_message.calls and "已返回任务列表" in cancel_message.calls[-1]["text"]
 
     asyncio.run(_scenario())
@@ -508,3 +510,119 @@ def test_task_service_search_tasks_empty_keyword(tmp_path):
     assert results == []
     assert pages == 0
     assert total == 0
+
+
+def test_format_task_detail_with_special_chars_markdown_v2(monkeypatch):
+    """测试修复：在 MarkdownV2 模式下避免双重转义特殊字符"""
+    # 模拟 MarkdownV2 模式
+    monkeypatch.setattr(bot, "_IS_MARKDOWN_V2", True)
+    monkeypatch.setattr(bot, "_IS_MARKDOWN", False)
+
+    # 创建包含特殊字符的任务
+    task = TaskRecord(
+        id="TASK_0001",
+        project_slug="demo",
+        title="修复登录-问题 (v2.0) [紧急]",
+        status="research",
+        priority=3,
+        task_type="defect",
+        tags=(),
+        due_date=None,
+        description="登录接口异常! 需要修复 test_case.example",
+        parent_id="TASK_0000",
+        root_id="TASK_0001",
+        depth=0,
+        lineage="0001",
+        created_at="2025-01-01T00:00:00+08:00",
+        updated_at="2025-01-01T00:00:00+08:00",
+        archived=False,
+    )
+
+    detail_text = bot._format_task_detail(task, notes=[])
+
+    # 在 MarkdownV2 模式下，特殊字符应该保持原样（不手动转义）
+    # 后续由 _prepare_model_payload() 统一转义
+    assert "修复登录-问题 (v2.0) [紧急]" in detail_text
+    assert "登录接口异常! 需要修复 test_case.example" in detail_text
+    assert "TASK_0000" in detail_text
+
+    # 确保没有双重转义（例如 \\- 或 \\( ）
+    assert "\\-" not in detail_text  # 避免 \- 再次被转义
+    assert "\\(" not in detail_text
+    assert "\\[" not in detail_text
+    assert "\\!" not in detail_text
+
+
+def test_format_task_detail_with_special_chars_legacy_markdown(monkeypatch):
+    """测试向后兼容：在传统 Markdown 模式下保持手动转义"""
+    # 模拟传统 Markdown 模式
+    monkeypatch.setattr(bot, "_IS_MARKDOWN_V2", False)
+    monkeypatch.setattr(bot, "_IS_MARKDOWN", True)
+
+    task = TaskRecord(
+        id="TASK_0002",
+        project_slug="demo",
+        title="修复_登录问题",
+        status="test",
+        priority=2,
+        task_type="task",
+        tags=(),
+        due_date=None,
+        description="测试*描述*",
+        parent_id=None,
+        root_id="TASK_0002",
+        depth=0,
+        lineage="0002",
+        created_at="2025-01-01T00:00:00+08:00",
+        updated_at="2025-01-01T00:00:00+08:00",
+        archived=False,
+    )
+
+    detail_text = bot._format_task_detail(task, notes=[])
+
+    # 在传统 Markdown 模式下，应该手动转义特殊字符
+    # _ 和 * 在 _MARKDOWN_ESCAPE_RE 中会被转义
+    assert "修复\\_登录问题" in detail_text  # _ 应该被转义为 \_
+    assert "测试\\*描述\\*" in detail_text  # * 应该被转义为 \*
+
+
+@pytest.mark.parametrize(
+    "title,status,task_type,description",
+    [
+        ("Fix [critical] bug", "research", "defect", "API endpoint /users fails"),
+        ("Update API (v2.0)", "test", "task", "Refactor code: clean up"),
+        ("任务#123! 解决问题.", "done", "requirement", "描述: 完成-测试"),
+        ("Test_case.example", "research", "task", "File path: /path/to/file.txt"),
+        ("含特殊符号: ~`>#+=|{}", "test", "risk", "注意事项"),
+    ],
+)
+def test_format_task_detail_various_special_chars(monkeypatch, title, status, task_type, description):
+    """测试各种特殊字符在 MarkdownV2 模式下的处理"""
+    monkeypatch.setattr(bot, "_IS_MARKDOWN_V2", True)
+    monkeypatch.setattr(bot, "_IS_MARKDOWN", False)
+
+    task = TaskRecord(
+        id="TASK_TEST",
+        project_slug="demo",
+        title=title,
+        status=status,
+        priority=3,
+        task_type=task_type,
+        tags=(),
+        due_date=None,
+        description=description,
+        parent_id=None,
+        root_id="TASK_TEST",
+        depth=0,
+        lineage="0001",
+        created_at="2025-01-01T00:00:00+08:00",
+        updated_at="2025-01-01T00:00:00+08:00",
+        archived=False,
+    )
+
+    # 不应该抛出异常
+    detail_text = bot._format_task_detail(task, notes=[])
+
+    # 标题和描述应该保持原样（在 MarkdownV2 模式下）
+    assert title in detail_text
+    assert description in detail_text
